@@ -42,7 +42,7 @@ __all__ = ('RPMWriter',)
 
 
 def normalize_deps(deps):
-    return ' '.join([d.strip(', ') for d in deps.split(' ') if d.strip(', ')])
+    return ' '.join([d.strip(' ') for d in deps.split(',') if d.strip(' ')])
 
 
 class RPMWriter(upack.write.Writer):
@@ -59,8 +59,9 @@ class RPMWriter(upack.write.Writer):
             epoch_line = 'Epoch:          {epoch}\n'
         else:
             epoch_line = ''
-        ctx.push({'build-requires': normalize_deps(ctx.format('{build-requires}')),
-                  'requires': normalize_deps(ctx.format('{requires}'))})
+        r = upack.context.Raw
+        ctx.push({'build-requires': r(normalize_deps(ctx.format('{build-requires}'))),
+                  'requires': r(normalize_deps(ctx.format('{requires}')))})
         pkg = ctx.format(
 '''Name:           {name}
 Version:        {version}
@@ -81,7 +82,7 @@ Conflicts:      {conflicts}
 ''')
         for subpackage in package.subpackages:
             ctx.push(subpackage)
-            ctx.push({'requires': normalize_deps(ctx.format('{requires}'))})
+            ctx.push({'requires': r(normalize_deps(ctx.format('{requires}')))})
             pkg += ctx.format(
 '''
 %package        -n {name}
